package de.fraunhofer.iem.dataprovider.gitlab

import de.fraunhofer.iem.dataprovider.toolResult.Tool
import de.fraunhofer.iem.dataprovider.toolResult.ToolRun
import jakarta.persistence.*
import java.util.*

@Entity
@Table(name = "repository")
class Repository {

    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    @Column(name = "id", nullable = false)
    var id: UUID? = null

    @OrderBy("time_stamp DESC")
    @OneToMany(
        mappedBy = "repository",
        cascade = [CascadeType.MERGE, CascadeType.REFRESH, CascadeType.REMOVE, CascadeType.DETACH],
        orphanRemoval = true
    )
    var toolRuns: MutableList<ToolRun> = mutableListOf()

    @Column(name = "name")
    var name: String? = null

    @Column(name = "repo_id")
    var repoId: Long? = null

    @Enumerated
    @Column(name = "platform")
    var platform: Platform? = null

    @Column(name = "url")
    var url: String? = null

    @ManyToMany
    @JoinTable(
        name = "repository_tools",
        joinColumns = [JoinColumn(name = "repository_id")],
        inverseJoinColumns = [JoinColumn(name = "tools_id")]
    )
    var tools: MutableSet<Tool> = mutableSetOf()

    fun addToolResults(toolRuns: Collection<ToolRun>) {
        toolRuns.forEach {
            this.addToolResult(it)
        }
    }

    fun addToolResult(toolRun: ToolRun) {
        toolRuns.add(toolRun)
        toolRun.repository = this
    }
}