package de.fraunhofer.iem.dataprovider.sarif

import kotlinx.serialization.SerialName
import kotlinx.serialization.Serializable


@Serializable
data class Sarif(
    @SerialName("runs")
    val runs: List<SarifRun>
)

@Serializable
data class SarifLocation(
    @SerialName("physicalLocation")
    val physicalLocation: SarifPhysicalLocation
)

@Serializable
data class SarifMessage(
    @SerialName("text")
    val text: String
)

@Serializable
data class SarifPhysicalLocation(
    @SerialName("artifactLocation")
    val artifactLocation: SarifArtifactLocation,
    @SerialName("region")
    val region: SarifRegion
)

@Serializable
data class SarifRegion(
    @SerialName("endColumn")
    val endColumn: Int,
    @SerialName("endLine")
    val endLine: Int,
    @SerialName("startColumn")
    val startColumn: Int,
    @SerialName("startLine")
    val startLine: Int
)

@Serializable
data class SarifResult(
    @SerialName("level")
    val level: String,
    @SerialName("locations")
    val locations: List<SarifLocation>,
    @SerialName("message")
    val message: SarifMessage,
    @SerialName("ruleId")
    val ruleId: String
)

@Serializable
data class SarifRule(
    @SerialName("helpUri")
    val helpUri: String,
    @SerialName("id")
    val id: String,
    @SerialName("name")
    val name: String,
    @SerialName("shortDescription")
    val shortDescription: SarifShortDescription
)

@Serializable
data class SarifRun(
    @SerialName("results")
    val results: List<SarifResult>,
    @SerialName("tool")
    val tool: SarifTool
)

@Serializable
data class SarifShortDescription(
    @SerialName("text")
    val text: String
)

@Serializable
data class SarifTool(
    @SerialName("driver")
    val driver: SarifDriver
)

@Serializable
data class SarifDriver(
    @SerialName("downloadUri")
    val downloadUri: String? = null,
    @SerialName("fullName")
    val fullName: String? = null,
    @SerialName("guid")
    val guid: String? = null,
    @SerialName("informationUri")
    val informationUri: String? = null,
    @SerialName("language")
    val language: String? = null,
    @SerialName("name")
    val name: String? = null,
    @SerialName("organization")
    val organization: String? = null,
    @SerialName("rules")
    val rules: List<SarifRule>,
    @SerialName("semanticVersion")
    val semanticVersion: String? = null,
    @SerialName("version")
    val version: String? = null
)

@Serializable
data class SarifArtifactLocation(
    @SerialName("uri")
    val uri: String
)
