package de.fraunhofer.iem.dataprovider.sarif

import de.fraunhofer.iem.dataprovider.toolResult.*
import kotlinx.serialization.decodeFromString
import kotlinx.serialization.json.Json
import java.io.IOException
import java.nio.file.Path
import java.sql.Timestamp
import java.time.Instant
import java.util.*

fun SarifRule.asDbObject(): Rule {
    val rule = Rule()
    rule.sarifRuleId = this.id
    rule.shortDescription = this.shortDescription.text
    return rule
}


fun SarifTool.asDbObject(): Tool {
    val tool = Tool()
    tool.fullName = this.driver.fullName
    tool.name = this.driver.name
    tool.version = this.driver.version
    return tool
}

fun SarifLocation.asDbObject(): Location {
    val location = Location()
    location.endColumn = this.physicalLocation.region.endColumn
    location.endLine = this.physicalLocation.region.endLine
    location.startColumn = this.physicalLocation.region.startColumn
    location.startLine = this.physicalLocation.region.startLine
    location.artifactLocation = this.physicalLocation.artifactLocation.uri
    return location
}

fun SarifResult.asDbObject(): Finding {
    val finding = Finding()

    when (this.level.uppercase(Locale.getDefault())) {
        "WARNING" -> finding.level = Level.Warning
        "ERROR" -> finding.level = Level.Error
        "NOTE" -> finding.level = Level.Note
        else -> finding.level = Level.None
    }

    finding.message = this.message.text
    finding.addLocations(this.locations.map { it.asDbObject() })

    return finding
}

fun SarifRun.asDbObject(): ToolRun {
    val tr = ToolRun()
    tr.timeStamp = Timestamp.from(Instant.now())
    return tr
}


fun getSarifFromFilePath(resultPath: Path): Sarif {
    val resFile = resultPath.toFile()
    if (resFile.exists()) {
        val resString = resFile.readText()
        val json = Json { ignoreUnknownKeys = true }
        return json.decodeFromString<Sarif>(resString)
    }

    throw IOException("File not found / Path is no file.")
}
